//******************************************************************************
//  Copyright (c) 2005-2013 by Jan Van hijfte
//
//  See the included file COPYING.TXT for details about the copyright.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//******************************************************************************



#ifndef CHANDLES_H
#define CHANDLES_H

#if defined _LP64
typedef long long int PTRINT;
typedef unsigned long long int PTRUINT;
#else
typedef int PTRINT;
typedef unsigned int PTRUINT;
#endif

typedef struct QAbstractButton__ { PTRINT dummy; } *QAbstractButtonH;
typedef struct QSizePolicy__ { PTRINT dummy; } *QSizePolicyH;
/* typedef struct QWebHistoryItem_hook__ { PTRINT dummy; } *QWebHistoryItem_hookH; */
typedef struct QSlider_hook__ { PTRINT dummy; } *QSlider_hookH;
typedef struct QGraphicsScene_hook__ { PTRINT dummy; } *QGraphicsScene_hookH;
typedef struct QSizeGrip__ { PTRINT dummy; } *QSizeGripH;
typedef struct QStyleOptionComboBox__ { PTRINT dummy; } *QStyleOptionComboBoxH;
typedef struct QTouchDevice__ { PTRINT dummy; } *QTouchDeviceH;
typedef struct QMdiSubWindow_hook__ { PTRINT dummy; } *QMdiSubWindow_hookH;
typedef struct QActionGroup_hook__ { PTRINT dummy; } *QActionGroup_hookH;
typedef struct QAbstractItemModel_hook__ { PTRINT dummy; } *QAbstractItemModel_hookH;
typedef struct QX11Info__ { PTRINT dummy; } *QX11InfoH;
typedef struct QAbstractSpinBox__ { PTRINT dummy; } *QAbstractSpinBoxH;
typedef struct QTreeView__ { PTRINT dummy; } *QTreeViewH;
typedef struct QPoint__ { PTRINT dummy; } *QPointH;
typedef struct QFontComboBox__ { PTRINT dummy; } *QFontComboBoxH;
typedef struct QGraphicsTextItem__ { PTRINT dummy; } *QGraphicsTextItemH;
typedef struct QWindow__ { PTRINT dummy; } *QWindowH;
typedef struct QGraphicsRectItem__ { PTRINT dummy; } *QGraphicsRectItemH;
typedef struct QComboBox_hook__ { PTRINT dummy; } *QComboBox_hookH;
typedef struct QSpacerItem__ { PTRINT dummy; } *QSpacerItemH;
typedef struct QCheckBox_hook__ { PTRINT dummy; } *QCheckBox_hookH;
typedef struct QModelIndex__ { PTRINT dummy; } *QModelIndexH;
typedef struct QLocale__ { PTRINT dummy; } *QLocaleH;
typedef struct QWidget__ { PTRINT dummy; } *QWidgetH;
typedef struct QRadialGradient__ { PTRINT dummy; } *QRadialGradientH;
typedef struct QStyle__ { PTRINT dummy; } *QStyleH;
typedef struct QFontComboBox_hook__ { PTRINT dummy; } *QFontComboBox_hookH;
typedef struct QWhatsThisClickedEvent__ { PTRINT dummy; } *QWhatsThisClickedEventH;
typedef struct QSwipeGesture__ { PTRINT dummy; } *QSwipeGestureH;
typedef struct QExposeEvent__ { PTRINT dummy; } *QExposeEventH;
typedef struct QAction_hook__ { PTRINT dummy; } *QAction_hookH;
typedef struct QTextLength__ { PTRINT dummy; } *QTextLengthH;
typedef struct QTextOption__ { PTRINT dummy; } *QTextOptionH;
typedef struct QStackedWidget_hook__ { PTRINT dummy; } *QStackedWidget_hookH;
typedef struct QMessageBox__ { PTRINT dummy; } *QMessageBoxH;
typedef struct QGesture__ { PTRINT dummy; } *QGestureH;
typedef struct QFileSystemWatcher__ { PTRINT dummy; } *QFileSystemWatcherH;
typedef struct QGestureEvent__ { PTRINT dummy; } *QGestureEventH;
typedef struct QTime__ { PTRINT dummy; } *QTimeH;
typedef struct QConicalGradient__ { PTRINT dummy; } *QConicalGradientH;
typedef struct QSystemTrayIcon_hook__ { PTRINT dummy; } *QSystemTrayIcon_hookH;
typedef struct QTreeWidgetItem_hook__ { PTRINT dummy; } *QTreeWidgetItem_hookH;
typedef struct QImageReader__ { PTRINT dummy; } *QImageReaderH;
typedef struct QRawFont__ { PTRINT dummy; } *QRawFontH;
typedef struct QNetworkCookie__ { PTRINT dummy; } *QNetworkCookieH;
typedef struct QMetaEnum__ { PTRINT dummy; } *QMetaEnumH;
/*typedef struct QWebHistoryInterface_hook__ { PTRINT dummy; } *QWebHistoryInterface_hookH;*/
typedef struct QPlainTextDocumentLayout_hook__ { PTRINT dummy; } *QPlainTextDocumentLayout_hookH;
/*typedef struct QLCLWebView__ { PTRINT dummy; } *QLCLWebViewH;*/
typedef struct QTextImageFormat__ { PTRINT dummy; } *QTextImageFormatH;
typedef struct QNetworkRequest__ { PTRINT dummy; } *QNetworkRequestH;
typedef struct QPrintPreviewWidget__ { PTRINT dummy; } *QPrintPreviewWidgetH;
typedef struct QCoreApplication__ { PTRINT dummy; } *QCoreApplicationH;
typedef struct QMainWindow_hook__ { PTRINT dummy; } *QMainWindow_hookH;
typedef struct QSpinBox_hook__ { PTRINT dummy; } *QSpinBox_hookH;
typedef struct QDataStream__ { PTRINT dummy; } *QDataStreamH;
typedef struct QByteArray__ { PTRINT dummy; } *QByteArrayH;
typedef struct QPrintPreviewDialog_hook__ { PTRINT dummy; } *QPrintPreviewDialog_hookH;
typedef struct QLCLAbstractSpinBox__ { PTRINT dummy; } *QLCLAbstractSpinBoxH;
typedef struct QMetaClassInfo__ { PTRINT dummy; } *QMetaClassInfoH;
typedef struct QImage__ { PTRINT dummy; } *QImageH;
typedef struct QTableView_hook__ { PTRINT dummy; } *QTableView_hookH;
typedef struct QNetworkProxyQuery__ { PTRINT dummy; } *QNetworkProxyQueryH;
typedef struct QTabWidget_hook__ { PTRINT dummy; } *QTabWidget_hookH;
typedef struct QTcpServer_hook__ { PTRINT dummy; } *QTcpServer_hookH;
typedef struct QStyleOptionGraphicsItem__ { PTRINT dummy; } *QStyleOptionGraphicsItemH;
typedef struct QPaintEngine__ { PTRINT dummy; } *QPaintEngineH;
typedef struct QHBoxLayout__ { PTRINT dummy; } *QHBoxLayoutH;
typedef struct QSplitter_hook__ { PTRINT dummy; } *QSplitter_hookH;
typedef struct QPainterPath__ { PTRINT dummy; } *QPainterPathH;
typedef struct QStandardItem_hook__ { PTRINT dummy; } *QStandardItem_hookH;
typedef struct QRegularExpressionValidator__ { PTRINT dummy; } *QRegularExpressionValidatorH;
typedef struct QGraphicsView__ { PTRINT dummy; } *QGraphicsViewH;
typedef struct QPaintDevice__ { PTRINT dummy; } *QPaintDeviceH;
typedef struct QHeaderView_hook__ { PTRINT dummy; } *QHeaderView_hookH;
typedef struct QNetworkProxy__ { PTRINT dummy; } *QNetworkProxyH;
typedef struct QSslCipher__ { PTRINT dummy; } *QSslCipherH;
typedef struct QEventLoop__ { PTRINT dummy; } *QEventLoopH;
typedef struct QHelpEvent__ { PTRINT dummy; } *QHelpEventH;
typedef struct QRegularExpression__ { PTRINT dummy; } *QRegularExpressionH;
typedef struct QUndoStack__ { PTRINT dummy; } *QUndoStackH;
typedef struct QEasingCurve__ { PTRINT dummy; } *QEasingCurveH;
/*typedef struct QWebPluginFactory__ { PTRINT dummy; } *QWebPluginFactoryH;*/
typedef struct QJsonDocument__ { PTRINT dummy; } *QJsonDocumentH;
typedef struct QTextObjectInterface_hook__ { PTRINT dummy; } *QTextObjectInterface_hookH;
typedef struct QPersistentModelIndex__ { PTRINT dummy; } *QPersistentModelIndexH;
typedef struct QStyleOption__ { PTRINT dummy; } *QStyleOptionH;
typedef struct QActionEvent__ { PTRINT dummy; } *QActionEventH;
/*typedef struct QWebSecurityOrigin_hook__ { PTRINT dummy; } *QWebSecurityOrigin_hookH;*/
typedef struct QTimer__ { PTRINT dummy; } *QTimerH;
typedef struct QTextObject__ { PTRINT dummy; } *QTextObjectH;
typedef struct QAbstractTableModel__ { PTRINT dummy; } *QAbstractTableModelH;
typedef struct QMovie__ { PTRINT dummy; } *QMovieH;
typedef struct QGestureRecognizer__ { PTRINT dummy; } *QGestureRecognizerH;
typedef struct QSslSocket__ { PTRINT dummy; } *QSslSocketH;
/*typedef struct QWebPage_hook__ { PTRINT dummy; } *QWebPage_hookH;*/
typedef struct QTableWidget_hook__ { PTRINT dummy; } *QTableWidget_hookH;
typedef struct QTapAndHoldGesture__ { PTRINT dummy; } *QTapAndHoldGestureH;
typedef struct QListWidgetItem__ { PTRINT dummy; } *QListWidgetItemH;
typedef struct QProgressBar__ { PTRINT dummy; } *QProgressBarH;
typedef struct QStyleOptionToolBox__ { PTRINT dummy; } *QStyleOptionToolBoxH;
typedef struct QMimeData__ { PTRINT dummy; } *QMimeDataH;
typedef struct QColor__ { PTRINT dummy; } *QColorH;
typedef struct QListView__ { PTRINT dummy; } *QListViewH;
typedef struct QFileOpenEvent__ { PTRINT dummy; } *QFileOpenEventH;
typedef struct QLCLThread__ { PTRINT dummy; } *QLCLThreadH;
typedef struct QGraphicsPixmapItem__ { PTRINT dummy; } *QGraphicsPixmapItemH;
typedef struct QSize__ { PTRINT dummy; } *QSizeH;
typedef struct QUdpSocket_hook__ { PTRINT dummy; } *QUdpSocket_hookH;
typedef struct QToolButton_hook__ { PTRINT dummy; } *QToolButton_hookH;
typedef struct QScrollBar__ { PTRINT dummy; } *QScrollBarH;
typedef struct QStatusBar__ { PTRINT dummy; } *QStatusBarH;
typedef struct QTextFormat__ { PTRINT dummy; } *QTextFormatH;
typedef struct QCursor__ { PTRINT dummy; } *QCursorH;
typedef struct QPrinter__ { PTRINT dummy; } *QPrinterH;
/*typedef struct QWebHistory_hook__ { PTRINT dummy; } *QWebHistory_hookH;*/
typedef struct QLCLMessageEvent__ { PTRINT dummy; } *QLCLMessageEventH;
typedef struct QKeySequence__ { PTRINT dummy; } *QKeySequenceH;
typedef struct QToolBar_hook__ { PTRINT dummy; } *QToolBar_hookH;
typedef struct QStyleOptionComplex__ { PTRINT dummy; } *QStyleOptionComplexH;
/*typedef struct QLCLWebPage__ { PTRINT dummy; } *QLCLWebPageH;*/
typedef struct QApplication_hook__ { PTRINT dummy; } *QApplication_hookH;
typedef struct QRect__ { PTRINT dummy; } *QRectH;
typedef struct QSessionManager__ { PTRINT dummy; } *QSessionManagerH;
typedef struct QPainterPathStroker__ { PTRINT dummy; } *QPainterPathStrokerH;
typedef struct QColorDialog__ { PTRINT dummy; } *QColorDialogH;
typedef struct QGuiApplication__ { PTRINT dummy; } *QGuiApplicationH;
typedef struct QItemDelegate__ { PTRINT dummy; } *QItemDelegateH;
typedef struct QTouchEvent__ { PTRINT dummy; } *QTouchEventH;
typedef struct QStandardItemModel_hook__ { PTRINT dummy; } *QStandardItemModel_hookH;
typedef struct QGraphicsScene__ { PTRINT dummy; } *QGraphicsSceneH;
/*typedef struct QWebHistoryItem__ { PTRINT dummy; } *QWebHistoryItemH;*/
typedef struct QDrag__ { PTRINT dummy; } *QDragH;
typedef struct QDir__ { PTRINT dummy; } *QDirH;
typedef struct QDesktopServices__ { PTRINT dummy; } *QDesktopServicesH;
typedef struct QTreeView_hook__ { PTRINT dummy; } *QTreeView_hookH;
typedef struct QMdiArea_hook__ { PTRINT dummy; } *QMdiArea_hookH;
typedef struct QTextList__ { PTRINT dummy; } *QTextListH;
typedef struct QHeaderView__ { PTRINT dummy; } *QHeaderViewH;
typedef struct QPrintDialog__ { PTRINT dummy; } *QPrintDialogH;
typedef struct QLineEdit__ { PTRINT dummy; } *QLineEditH;
typedef struct QWhatsThis__ { PTRINT dummy; } *QWhatsThisH;
typedef struct QStyleOptionDockWidget__ { PTRINT dummy; } *QStyleOptionDockWidgetH;
typedef struct QDoubleSpinBox_hook__ { PTRINT dummy; } *QDoubleSpinBox_hookH;
typedef struct QBuffer__ { PTRINT dummy; } *QBufferH;
typedef struct QFileDevice__ { PTRINT dummy; } *QFileDeviceH;
typedef struct QMdiArea__ { PTRINT dummy; } *QMdiAreaH;
typedef struct QFile__ { PTRINT dummy; } *QFileH;
typedef struct QTreeWidget_hook__ { PTRINT dummy; } *QTreeWidget_hookH;
typedef struct QTextFragment__ { PTRINT dummy; } *QTextFragmentH;
typedef struct QSizeF__ { PTRINT dummy; } *QSizeFH;
typedef struct QRegion__ { PTRINT dummy; } *QRegionH;
typedef struct QThread__ { PTRINT dummy; } *QThreadH;
typedef struct QMenuBar_hook__ { PTRINT dummy; } *QMenuBar_hookH;
typedef struct QDoubleValidator__ { PTRINT dummy; } *QDoubleValidatorH;
typedef struct QGraphicsEllipseItem__ { PTRINT dummy; } *QGraphicsEllipseItemH;
typedef struct QLCDNumber__ { PTRINT dummy; } *QLCDNumberH;
typedef struct QPixmap__ { PTRINT dummy; } *QPixmapH;
typedef struct QTextBlockFormat__ { PTRINT dummy; } *QTextBlockFormatH;
/*typedef struct QWebHitTestResult_hook__ { PTRINT dummy; } *QWebHitTestResult_hookH;*/
typedef struct QDesktopWidget_hook__ { PTRINT dummy; } *QDesktopWidget_hookH;
typedef struct QAbstractPrintDialog_hook__ { PTRINT dummy; } *QAbstractPrintDialog_hookH;
typedef struct QContextMenuEvent__ { PTRINT dummy; } *QContextMenuEventH;
typedef struct QSystemTrayIcon__ { PTRINT dummy; } *QSystemTrayIconH;
typedef struct QTextObjectInterface__ { PTRINT dummy; } *QTextObjectInterfaceH;
typedef struct QUuid__ { PTRINT dummy; } *QUuidH;
typedef struct QTreeWidget__ { PTRINT dummy; } *QTreeWidgetH;
typedef struct QValidator__ { PTRINT dummy; } *QValidatorH;
typedef struct QDialog_hook__ { PTRINT dummy; } *QDialog_hookH;
typedef struct QStyleOptionProgressBar__ { PTRINT dummy; } *QStyleOptionProgressBarH;
typedef struct QMdiSubWindow__ { PTRINT dummy; } *QMdiSubWindowH;
typedef struct QIconDragEvent__ { PTRINT dummy; } *QIconDragEventH;
typedef struct QStatusTipEvent__ { PTRINT dummy; } *QStatusTipEventH;
typedef struct QTableWidget__ { PTRINT dummy; } *QTableWidgetH;
typedef struct QStyleOptionSlider__ { PTRINT dummy; } *QStyleOptionSliderH;
typedef struct QBitArray__ { PTRINT dummy; } *QBitArrayH;
typedef struct QPushButton__ { PTRINT dummy; } *QPushButtonH;
typedef struct QPrintPreviewWidget_hook__ { PTRINT dummy; } *QPrintPreviewWidget_hookH;
typedef struct QUrlQuery__ { PTRINT dummy; } *QUrlQueryH;
typedef struct QToolBar__ { PTRINT dummy; } *QToolBarH;
typedef struct QScrollBar_hook__ { PTRINT dummy; } *QScrollBar_hookH;
typedef struct QDoubleSpinBox__ { PTRINT dummy; } *QDoubleSpinBoxH;
typedef struct QAbstractScrollArea__ { PTRINT dummy; } *QAbstractScrollAreaH;
typedef struct QCoreApplication_hook__ { PTRINT dummy; } *QCoreApplication_hookH;
typedef struct QImageIOHandler__ { PTRINT dummy; } *QImageIOHandlerH;
typedef struct QGraphicsPathItem__ { PTRINT dummy; } *QGraphicsPathItemH;
typedef struct QEvent__ { PTRINT dummy; } *QEventH;
/*typedef struct QWebSecurityOrigin__ { PTRINT dummy; } *QWebSecurityOriginH;*/
typedef struct QSslConfiguration__ { PTRINT dummy; } *QSslConfigurationH;
typedef struct QAbstractSlider__ { PTRINT dummy; } *QAbstractSliderH;
/*typedef struct QWebPage__ { PTRINT dummy; } *QWebPageH;*/
typedef struct QStyleOptionFrame__ { PTRINT dummy; } *QStyleOptionFrameH;
typedef struct QMouseEvent__ { PTRINT dummy; } *QMouseEventH;
typedef struct QProgressDialog_hook__ { PTRINT dummy; } *QProgressDialog_hookH;
typedef struct QNetworkCookieJar__ { PTRINT dummy; } *QNetworkCookieJarH;
typedef struct QFontInfo__ { PTRINT dummy; } *QFontInfoH;
typedef struct QIntValidator__ { PTRINT dummy; } *QIntValidatorH;
typedef struct QMatrix__ { PTRINT dummy; } *QMatrixH;
typedef struct QAbstractItemModel__ { PTRINT dummy; } *QAbstractItemModelH;
typedef struct QSpinBox__ { PTRINT dummy; } *QSpinBoxH;
typedef struct QTextDocument__ { PTRINT dummy; } *QTextDocumentH;
typedef struct QPersistentModelIndex_hook__ { PTRINT dummy; } *QPersistentModelIndex_hookH;
typedef struct QLCLTabWidget__ { PTRINT dummy; } *QLCLTabWidgetH;
typedef struct QProcess__ { PTRINT dummy; } *QProcessH;
typedef struct QPlainTextEdit_hook__ { PTRINT dummy; } *QPlainTextEdit_hookH;
typedef struct QDragEnterEvent__ { PTRINT dummy; } *QDragEnterEventH;
typedef struct QImageWriter__ { PTRINT dummy; } *QImageWriterH;
/*typedef struct QWebSettings_hook__ { PTRINT dummy; } *QWebSettings_hookH;*/
typedef struct QProcess_hook__ { PTRINT dummy; } *QProcess_hookH;
typedef struct QAbstractItemDelegate_hook__ { PTRINT dummy; } *QAbstractItemDelegate_hookH;
typedef struct QStackedLayout_hook__ { PTRINT dummy; } *QStackedLayout_hookH;
typedef struct QActionGroup__ { PTRINT dummy; } *QActionGroupH;
typedef struct QItemEditorCreatorBase__ { PTRINT dummy; } *QItemEditorCreatorBaseH;
typedef struct QToolBox_hook__ { PTRINT dummy; } *QToolBox_hookH;
typedef struct QWidgetItem__ { PTRINT dummy; } *QWidgetItemH;
typedef struct QMenu_hook__ { PTRINT dummy; } *QMenu_hookH;
typedef struct QPolygonF__ { PTRINT dummy; } *QPolygonFH;
typedef struct QLayout__ { PTRINT dummy; } *QLayoutH;
typedef struct QTextCharFormat__ { PTRINT dummy; } *QTextCharFormatH;
typedef struct QPagedPaintDevice__ { PTRINT dummy; } *QPagedPaintDeviceH;
typedef struct QStyleHintReturn__ { PTRINT dummy; } *QStyleHintReturnH;
typedef struct QGuiApplication_hook__ { PTRINT dummy; } *QGuiApplication_hookH;
typedef struct QBackingStore__ { PTRINT dummy; } *QBackingStoreH;
typedef struct QItemSelectionModel__ { PTRINT dummy; } *QItemSelectionModelH;
typedef struct QStyleOptionHeader__ { PTRINT dummy; } *QStyleOptionHeaderH;
typedef struct QWheelEvent__ { PTRINT dummy; } *QWheelEventH;
typedef struct QPolygon__ { PTRINT dummy; } *QPolygonH;
typedef struct QStringList__ { PTRINT dummy; } *QStringListH;
typedef struct QRegExp__ { PTRINT dummy; } *QRegExpH;
typedef struct QGenericReturnArgument__ { PTRINT dummy; } *QGenericReturnArgumentH;
typedef struct QTextLine__ { PTRINT dummy; } *QTextLineH;
typedef struct QTextBlockUserData__ { PTRINT dummy; } *QTextBlockUserDataH;
typedef struct QPrintDialog_hook__ { PTRINT dummy; } *QPrintDialog_hookH;
typedef struct QUrl__ { PTRINT dummy; } *QUrlH;
typedef struct QTextEdit__ { PTRINT dummy; } *QTextEditH;
typedef struct QNetworkProxyFactory__ { PTRINT dummy; } *QNetworkProxyFactoryH;
typedef struct QCheckBox__ { PTRINT dummy; } *QCheckBoxH;
typedef struct QTcpSocket_hook__ { PTRINT dummy; } *QTcpSocket_hookH;
typedef struct QListWidgetItem_hook__ { PTRINT dummy; } *QListWidgetItem_hookH;
typedef struct QItemEditorFactory__ { PTRINT dummy; } *QItemEditorFactoryH;
typedef struct QFileIconProvider__ { PTRINT dummy; } *QFileIconProviderH;
typedef struct QPainter__ { PTRINT dummy; } *QPainterH;
typedef struct QVariant__ { PTRINT dummy; } *QVariantH;
typedef struct QTextLayout__ { PTRINT dummy; } *QTextLayoutH;
typedef struct QScrollEvent__ { PTRINT dummy; } *QScrollEventH;
typedef struct QHoverEvent__ { PTRINT dummy; } *QHoverEventH;
typedef struct QTabBar_hook__ { PTRINT dummy; } *QTabBar_hookH;
typedef struct QNetworkReply_hook__ { PTRINT dummy; } *QNetworkReply_hookH;
typedef struct QCompleter__ { PTRINT dummy; } *QCompleterH;
typedef struct QGroupBox__ { PTRINT dummy; } *QGroupBoxH;
typedef struct QThread_hook__ { PTRINT dummy; } *QThread_hookH;
typedef struct QTextFrame__ { PTRINT dummy; } *QTextFrameH;
typedef struct QGraphicsEffect__ { PTRINT dummy; } *QGraphicsEffectH;
typedef struct QPlainTextDocumentLayout__ { PTRINT dummy; } *QPlainTextDocumentLayoutH;
typedef struct QLinearGradient__ { PTRINT dummy; } *QLinearGradientH;
typedef struct QTextFrameFormat__ { PTRINT dummy; } *QTextFrameFormatH;
typedef struct QItemSelectionRange_hook__ { PTRINT dummy; } *QItemSelectionRange_hookH;
typedef struct QStandardItemModel__ { PTRINT dummy; } *QStandardItemModelH;
/*typedef struct QWebView_hook__ { PTRINT dummy; } *QWebView_hookH;*/
/*typedef struct QWebHitTestResult__ { PTRINT dummy; } *QWebHitTestResultH;*/
typedef struct QPicture__ { PTRINT dummy; } *QPictureH;
typedef struct QStackedWidget__ { PTRINT dummy; } *QStackedWidgetH;
typedef struct QStyleHintReturnVariant__ { PTRINT dummy; } *QStyleHintReturnVariantH;
typedef struct QStyleOptionFocusRect__ { PTRINT dummy; } *QStyleOptionFocusRectH;
typedef struct QFontDatabase__ { PTRINT dummy; } *QFontDatabaseH;
typedef struct QFontMetrics__ { PTRINT dummy; } *QFontMetricsH;
typedef struct QDialog__ { PTRINT dummy; } *QDialogH;
typedef struct QDragMoveEvent__ { PTRINT dummy; } *QDragMoveEventH;
typedef struct QTabWidget__ { PTRINT dummy; } *QTabWidgetH;
typedef struct QTableWidgetSelectionRange__ { PTRINT dummy; } *QTableWidgetSelectionRangeH;
typedef struct QBrush__ { PTRINT dummy; } *QBrushH;
typedef struct QInputMethod__ { PTRINT dummy; } *QInputMethodH;
typedef struct QIconEngine__ { PTRINT dummy; } *QIconEngineH;
typedef struct QSplitter__ { PTRINT dummy; } *QSplitterH;
typedef struct QAbstractTableModel_hook__ { PTRINT dummy; } *QAbstractTableModel_hookH;
typedef struct QTableWidgetSelectionRange_hook__ { PTRINT dummy; } *QTableWidgetSelectionRange_hookH;
typedef struct QToolBox__ { PTRINT dummy; } *QToolBoxH;
typedef struct QGraphicsPolygonItem__ { PTRINT dummy; } *QGraphicsPolygonItemH;
typedef struct QTabletEvent__ { PTRINT dummy; } *QTabletEventH;
typedef struct QStatusBar_hook__ { PTRINT dummy; } *QStatusBar_hookH;
typedef struct QAbstractPrintDialog__ { PTRINT dummy; } *QAbstractPrintDialogH;
typedef struct QScreenOrientationChangeEvent__ { PTRINT dummy; } *QScreenOrientationChangeEventH;
typedef struct QChar__ { PTRINT dummy; } *QCharH;
typedef struct QTransform__ { PTRINT dummy; } *QTransformH;
typedef struct QUdpSocket__ { PTRINT dummy; } *QUdpSocketH;
typedef struct QClipboard_hook__ { PTRINT dummy; } *QClipboard_hookH;
typedef struct QTcpSocket__ { PTRINT dummy; } *QTcpSocketH;
typedef struct QShowEvent__ { PTRINT dummy; } *QShowEventH;
typedef struct QPageSetupDialog__ { PTRINT dummy; } *QPageSetupDialogH;
typedef struct QPanGesture__ { PTRINT dummy; } *QPanGestureH;
typedef struct QLabel_hook__ { PTRINT dummy; } *QLabel_hookH;
typedef struct QTabBar__ { PTRINT dummy; } *QTabBarH;
typedef struct QNetworkAccessManager_hook__ { PTRINT dummy; } *QNetworkAccessManager_hookH;
typedef struct QSplitterHandle_hook__ { PTRINT dummy; } *QSplitterHandle_hookH;
typedef struct QSslKey__ { PTRINT dummy; } *QSslKeyH;
typedef struct QLCLAbstractScrollArea__ { PTRINT dummy; } *QLCLAbstractScrollAreaH;
typedef struct QScrollArea__ { PTRINT dummy; } *QScrollAreaH;
typedef struct QProgressDialog__ { PTRINT dummy; } *QProgressDialogH;
typedef struct QWinEventNotifier__ { PTRINT dummy; } *QWinEventNotifierH;
typedef struct QProcessEnvironment_hook__ { PTRINT dummy; } *QProcessEnvironment_hookH;
typedef struct QPaintEvent__ { PTRINT dummy; } *QPaintEventH;
typedef struct QCalendarWidget_hook__ { PTRINT dummy; } *QCalendarWidget_hookH;
typedef struct QTcpServer__ { PTRINT dummy; } *QTcpServerH;
typedef struct QListWidget__ { PTRINT dummy; } *QListWidgetH;
typedef struct QStyleOptionTab__ { PTRINT dummy; } *QStyleOptionTabH;
/*typedef struct QWebDatabase__ { PTRINT dummy; } *QWebDatabaseH;*/
typedef struct QInputDialog__ { PTRINT dummy; } *QInputDialogH;
typedef struct QAbstractListModel__ { PTRINT dummy; } *QAbstractListModelH;
typedef struct QDynamicPropertyChangeEvent__ { PTRINT dummy; } *QDynamicPropertyChangeEventH;
typedef struct QRegularExpressionMatch__ { PTRINT dummy; } *QRegularExpressionMatchH;
typedef struct QAbstractSpinBox_hook__ { PTRINT dummy; } *QAbstractSpinBox_hookH;
typedef struct QGradient__ { PTRINT dummy; } *QGradientH;
typedef struct QAbstractListModel_hook__ { PTRINT dummy; } *QAbstractListModel_hookH;
typedef struct QGraphicsWidget__ { PTRINT dummy; } *QGraphicsWidgetH;
typedef struct QGlyphRun__ { PTRINT dummy; } *QGlyphRunH;
typedef struct QFocusEvent__ { PTRINT dummy; } *QFocusEventH;
typedef struct QSslCertificate__ { PTRINT dummy; } *QSslCertificateH;
typedef struct QPointF__ { PTRINT dummy; } *QPointFH;
typedef struct QAbstractSlider_hook__ { PTRINT dummy; } *QAbstractSlider_hookH;
typedef struct QEventLoopLocker__ { PTRINT dummy; } *QEventLoopLockerH;
typedef struct QToolButton__ { PTRINT dummy; } *QToolButtonH;
typedef struct QListWidget_hook__ { PTRINT dummy; } *QListWidget_hookH;
typedef struct QMetaProperty__ { PTRINT dummy; } *QMetaPropertyH;
typedef struct QStyleHints__ { PTRINT dummy; } *QStyleHintsH;
typedef struct QDateTime__ { PTRINT dummy; } *QDateTimeH;
typedef struct QPrintPreviewDialog__ { PTRINT dummy; } *QPrintPreviewDialogH;
typedef struct QGraphicsLineItem__ { PTRINT dummy; } *QGraphicsLineItemH;
typedef struct QAbstractTextDocumentLayout__ { PTRINT dummy; } *QAbstractTextDocumentLayoutH;
typedef struct QRectF__ { PTRINT dummy; } *QRectFH;
typedef struct QScrollPrepareEvent__ { PTRINT dummy; } *QScrollPrepareEventH;
typedef struct QGraphicsProxyWidget__ { PTRINT dummy; } *QGraphicsProxyWidgetH;
typedef struct QIODevice_hook__ { PTRINT dummy; } *QIODevice_hookH;
typedef struct QStyleOptionRubberBand__ { PTRINT dummy; } *QStyleOptionRubberBandH;
typedef struct QEnterEvent__ { PTRINT dummy; } *QEnterEventH;
typedef struct QShortcut__ { PTRINT dummy; } *QShortcutH;
typedef struct QRubberBand__ { PTRINT dummy; } *QRubberBandH;
typedef struct QAbstractEventDispatcher__ { PTRINT dummy; } *QAbstractEventDispatcherH;
typedef struct QScreen__ { PTRINT dummy; } *QScreenH;
typedef struct QClipboard__ { PTRINT dummy; } *QClipboardH;
typedef struct QStyleOptionMenuItem__ { PTRINT dummy; } *QStyleOptionMenuItemH;
typedef struct QMenu__ { PTRINT dummy; } *QMenuH;
typedef struct QStyleFactory__ { PTRINT dummy; } *QStyleFactoryH;
/*typedef struct QWebFrame_hook__ { PTRINT dummy; } *QWebFrame_hookH;*/
typedef struct QCloseEvent__ { PTRINT dummy; } *QCloseEventH;
typedef struct QGraphicsItemGroup__ { PTRINT dummy; } *QGraphicsItemGroupH;
typedef struct QTableWidgetItem_hook__ { PTRINT dummy; } *QTableWidgetItem_hookH;
/*typedef struct QWebView__ { PTRINT dummy; } *QWebViewH;*/
typedef struct QItemSelectionRange__ { PTRINT dummy; } *QItemSelectionRangeH;
typedef struct QApplication__ { PTRINT dummy; } *QApplicationH;
typedef struct QMoveEvent__ { PTRINT dummy; } *QMoveEventH;
typedef struct QNetworkReply__ { PTRINT dummy; } *QNetworkReplyH;
/*typedef struct QWebElement__ { PTRINT dummy; } *QWebElementH;*/
typedef struct QStaticText__ { PTRINT dummy; } *QStaticTextH;
typedef struct QPalette__ { PTRINT dummy; } *QPaletteH;
typedef struct QAbstractItemView__ { PTRINT dummy; } *QAbstractItemViewH;
typedef struct QTextCursor__ { PTRINT dummy; } *QTextCursorH;
typedef struct QAbstractSocket_hook__ { PTRINT dummy; } *QAbstractSocket_hookH;
typedef struct QAbstractTextDocumentLayout_hook__ { PTRINT dummy; } *QAbstractTextDocumentLayout_hookH;
typedef struct QStandardItem__ { PTRINT dummy; } *QStandardItemH;
typedef struct QNetworkInterface__ { PTRINT dummy; } *QNetworkInterfaceH;
typedef struct QStyleOptionButton__ { PTRINT dummy; } *QStyleOptionButtonH;
typedef struct QTapGesture__ { PTRINT dummy; } *QTapGestureH;
typedef struct QDropEvent__ { PTRINT dummy; } *QDropEventH;
typedef struct QLCDNumber_hook__ { PTRINT dummy; } *QLCDNumber_hookH;
typedef struct QSocketNotifier__ { PTRINT dummy; } *QSocketNotifierH;
typedef struct QAbstractNetworkCache__ { PTRINT dummy; } *QAbstractNetworkCacheH;
typedef struct QFontMetricsF__ { PTRINT dummy; } *QFontMetricsFH;
typedef struct QLayoutItem__ { PTRINT dummy; } *QLayoutItemH;
typedef struct QFrame__ { PTRINT dummy; } *QFrameH;
typedef struct QHideEvent__ { PTRINT dummy; } *QHideEventH;
typedef struct QSocketNotifier_hook__ { PTRINT dummy; } *QSocketNotifier_hookH;
typedef struct QDesktopWidget__ { PTRINT dummy; } *QDesktopWidgetH;
typedef struct QModelIndex_hook__ { PTRINT dummy; } *QModelIndex_hookH;
typedef struct QDragLeaveEvent__ { PTRINT dummy; } *QDragLeaveEventH;
typedef struct QHttpMultiPart__ { PTRINT dummy; } *QHttpMultiPartH;
typedef struct QTextTableCellFormat__ { PTRINT dummy; } *QTextTableCellFormatH;
typedef struct QPrintEngine__ { PTRINT dummy; } *QPrintEngineH;
typedef struct QItemSelectionModel_hook__ { PTRINT dummy; } *QItemSelectionModel_hookH;
typedef struct QMainWindow__ { PTRINT dummy; } *QMainWindowH;
typedef struct QTextTableFormat__ { PTRINT dummy; } *QTextTableFormatH;
typedef struct QProcessEnvironment__ { PTRINT dummy; } *QProcessEnvironmentH;
typedef struct QFileDialog_hook__ { PTRINT dummy; } *QFileDialog_hookH;
typedef struct QTextInlineObject__ { PTRINT dummy; } *QTextInlineObjectH;
typedef struct QRadioButton__ { PTRINT dummy; } *QRadioButtonH;
typedef struct QStyleHintReturnMask__ { PTRINT dummy; } *QStyleHintReturnMaskH;
/*typedef struct QWebHistory__ { PTRINT dummy; } *QWebHistoryH;*/
typedef struct QComboBox__ { PTRINT dummy; } *QComboBoxH;
typedef struct QTableView__ { PTRINT dummy; } *QTableViewH;
typedef struct QTextEdit_hook__ { PTRINT dummy; } *QTextEdit_hookH;
typedef struct QGridLayout__ { PTRINT dummy; } *QGridLayoutH;
typedef struct QAbstractItemDelegate__ { PTRINT dummy; } *QAbstractItemDelegateH;
typedef struct QStyleOptionToolButton__ { PTRINT dummy; } *QStyleOptionToolButtonH;
typedef struct QLineEdit_hook__ { PTRINT dummy; } *QLineEdit_hookH;
typedef struct QTextBrowser__ { PTRINT dummy; } *QTextBrowserH;
typedef struct QFont__ { PTRINT dummy; } *QFontH;
typedef struct QAbstractButton_hook__ { PTRINT dummy; } *QAbstractButton_hookH;
typedef struct QStackedLayout__ { PTRINT dummy; } *QStackedLayoutH;
typedef struct QTextDocumentFragment__ { PTRINT dummy; } *QTextDocumentFragmentH;
typedef struct QInputEvent__ { PTRINT dummy; } *QInputEventH;
typedef struct QGroupBox_hook__ { PTRINT dummy; } *QGroupBox_hookH;
/*typedef struct QWebSettings__ { PTRINT dummy; } *QWebSettingsH;*/
typedef struct QSlider__ { PTRINT dummy; } *QSliderH;
typedef struct QMetaObject__ { PTRINT dummy; } *QMetaObjectH;
typedef struct QTextBlock__ { PTRINT dummy; } *QTextBlockH;
typedef struct QJsonValue__ { PTRINT dummy; } *QJsonValueH;
typedef struct QFileInfo__ { PTRINT dummy; } *QFileInfoH;
typedef struct QAuthenticator__ { PTRINT dummy; } *QAuthenticatorH;
typedef struct QVBoxLayout__ { PTRINT dummy; } *QVBoxLayoutH;
typedef struct QTableWidgetItem__ { PTRINT dummy; } *QTableWidgetItemH;
typedef struct QLayout_hook__ { PTRINT dummy; } *QLayout_hookH;
typedef struct QStyledItemDelegate__ { PTRINT dummy; } *QStyledItemDelegateH;
typedef struct QStyleOptionSizeGrip__ { PTRINT dummy; } *QStyleOptionSizeGripH;
/*typedef struct QWebElementCollection__ { PTRINT dummy; } *QWebElementCollectionH;*/
typedef struct QTextListFormat__ { PTRINT dummy; } *QTextListFormatH;
typedef struct QBitmap__ { PTRINT dummy; } *QBitmapH;
typedef struct QPinchGesture__ { PTRINT dummy; } *QPinchGestureH;
typedef struct QApplicationStateChangeEvent__ { PTRINT dummy; } *QApplicationStateChangeEventH;
typedef struct QTimerEvent__ { PTRINT dummy; } *QTimerEventH;
typedef struct QAbstractItemView_hook__ { PTRINT dummy; } *QAbstractItemView_hookH;
typedef struct QHostAddress__ { PTRINT dummy; } *QHostAddressH;
typedef struct QButtonGroup_hook__ { PTRINT dummy; } *QButtonGroup_hookH;
typedef struct QInputMethodEvent__ { PTRINT dummy; } *QInputMethodEventH;
typedef struct QDate__ { PTRINT dummy; } *QDateH;
typedef struct QStyleOptionTitleBar__ { PTRINT dummy; } *QStyleOptionTitleBarH;
typedef struct QWidget_hook__ { PTRINT dummy; } *QWidget_hookH;
typedef struct QDockWidget__ { PTRINT dummy; } *QDockWidgetH;
typedef struct QLine__ { PTRINT dummy; } *QLineH;
typedef struct QTextCodec__ { PTRINT dummy; } *QTextCodecH;
typedef struct QNetworkConfiguration__ { PTRINT dummy; } *QNetworkConfigurationH;
/*typedef struct QWebFrame__ { PTRINT dummy; } *QWebFrameH;*/
typedef struct QObject_hook__ { PTRINT dummy; } *QObject_hookH;
typedef struct QTextBlockGroup__ { PTRINT dummy; } *QTextBlockGroupH;
typedef struct QStyleOptionViewItem__ { PTRINT dummy; } *QStyleOptionViewItemH;
typedef struct QJsonArray__ { PTRINT dummy; } *QJsonArrayH;
typedef struct QButtonGroup__ { PTRINT dummy; } *QButtonGroupH;
typedef struct QTextBrowser_hook__ { PTRINT dummy; } *QTextBrowser_hookH;
typedef struct QMargins__ { PTRINT dummy; } *QMarginsH;
typedef struct QShortcut_hook__ { PTRINT dummy; } *QShortcut_hookH;
typedef struct QAbstractNativeEventFilter__ { PTRINT dummy; } *QAbstractNativeEventFilterH;
typedef struct QListView_hook__ { PTRINT dummy; } *QListView_hookH;
typedef struct QStyleOptionGroupBox__ { PTRINT dummy; } *QStyleOptionGroupBoxH;
typedef struct QStyleOptionTabBarBase__ { PTRINT dummy; } *QStyleOptionTabBarBaseH;
typedef struct QProgressBar_hook__ { PTRINT dummy; } *QProgressBar_hookH;
typedef struct QTreeWidgetItem__ { PTRINT dummy; } *QTreeWidgetItemH;
/*typedef struct QWebHistoryInterface__ { PTRINT dummy; } *QWebHistoryInterfaceH;*/
typedef struct QChildEvent__ { PTRINT dummy; } *QChildEventH;
typedef struct QGraphicsItem__ { PTRINT dummy; } *QGraphicsItemH;
typedef struct QKeyEvent__ { PTRINT dummy; } *QKeyEventH;
typedef struct QAction__ { PTRINT dummy; } *QActionH;
typedef struct QToolTip__ { PTRINT dummy; } *QToolTipH;
typedef struct QLCLItemDelegate__ { PTRINT dummy; } *QLCLItemDelegateH;
typedef struct QJsonObject__ { PTRINT dummy; } *QJsonObjectH;
typedef struct QDrag_hook__ { PTRINT dummy; } *QDrag_hookH;
typedef struct QBoxLayout__ { PTRINT dummy; } *QBoxLayoutH;
typedef struct QTimer_hook__ { PTRINT dummy; } *QTimer_hookH;
typedef struct QStyleOptionSpinBox__ { PTRINT dummy; } *QStyleOptionSpinBoxH;
typedef struct QIcon__ { PTRINT dummy; } *QIconH;
typedef struct QPlainTextEdit__ { PTRINT dummy; } *QPlainTextEditH;
typedef struct QLineF__ { PTRINT dummy; } *QLineFH;
typedef struct QWindowStateChangeEvent__ { PTRINT dummy; } *QWindowStateChangeEventH;
typedef struct QSslError__ { PTRINT dummy; } *QSslErrorH;
typedef struct QString__ { PTRINT dummy; } *QStringH;
typedef struct QFrame_hook__ { PTRINT dummy; } *QFrame_hookH;
typedef struct QTextDocumentWriter__ { PTRINT dummy; } *QTextDocumentWriterH;
typedef struct QAbstractScrollArea_hook__ { PTRINT dummy; } *QAbstractScrollArea_hookH;
typedef struct QFileDialog__ { PTRINT dummy; } *QFileDialogH;
/*typedef struct QWebDatabase_hook__ { PTRINT dummy; } *QWebDatabase_hookH;*/
typedef struct QAbstractProxyModel__ { PTRINT dummy; } *QAbstractProxyModelH;
typedef struct QTranslator__ { PTRINT dummy; } *QTranslatorH;
typedef struct QObject__ { PTRINT dummy; } *QObjectH;
typedef struct QRegExpValidator__ { PTRINT dummy; } *QRegExpValidatorH;
typedef struct QFontDialog__ { PTRINT dummy; } *QFontDialogH;
typedef struct QAbstractSocket__ { PTRINT dummy; } *QAbstractSocketH;
typedef struct QLabel__ { PTRINT dummy; } *QLabelH;
typedef struct QStyleOptionToolBar__ { PTRINT dummy; } *QStyleOptionToolBarH;
typedef struct QPrinterInfo__ { PTRINT dummy; } *QPrinterInfoH;
typedef struct QStyleOptionTabWidgetFrame__ { PTRINT dummy; } *QStyleOptionTabWidgetFrameH;
typedef struct QPen__ { PTRINT dummy; } *QPenH;
typedef struct QIODevice__ { PTRINT dummy; } *QIODeviceH;
typedef struct QMetaMethod__ { PTRINT dummy; } *QMetaMethodH;
typedef struct QResizeEvent__ { PTRINT dummy; } *QResizeEventH;
typedef struct QMenuBar__ { PTRINT dummy; } *QMenuBarH;
typedef struct QNetworkAccessManager__ { PTRINT dummy; } *QNetworkAccessManagerH;
typedef struct QShortcutEvent__ { PTRINT dummy; } *QShortcutEventH;
typedef struct QPushButton_hook__ { PTRINT dummy; } *QPushButton_hookH;
typedef struct QTextTable__ { PTRINT dummy; } *QTextTableH;
typedef struct QGraphicsSimpleTextItem__ { PTRINT dummy; } *QGraphicsSimpleTextItemH;
typedef struct QDockWidget_hook__ { PTRINT dummy; } *QDockWidget_hookH;
typedef struct QSplitterHandle__ { PTRINT dummy; } *QSplitterHandleH;
typedef struct QCalendarWidget__ { PTRINT dummy; } *QCalendarWidgetH;
typedef struct QFileSystemWatcher_hook__ { PTRINT dummy; } *QFileSystemWatcher_hookH;
typedef struct QInputMethodQueryEvent__ { PTRINT dummy; } *QInputMethodQueryEventH;
#endif
